#pragma once

extern "C" {
    #include SDBUS_HEADER
}

extern const sd_bus_vtable musikcube_mp_table[];
extern const sd_bus_vtable musikcube_mpp_table[];
